@@ -1,19 +1,34 @@
-// Copyright (C) 2000-2010 Heiko Bauke <heiko.bauke@mpi-hd.mpg.de>
-//  
-// This program is free software; you can redistribute it and/or
-// modify it under the terms of the GNU General Public License in
-// version 2 as published by the Free Software Foundation.
-//  
-// This program is distributed in the hope that it will be useful, but
-// WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-// General Public License for more details.
-//  
-// You should have received a copy of the GNU General Public License
-// along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
-//  
+// Copyright (c) 2000-2010, Heiko Bauke
+// All rights reserved.
+// 
+// Redistribution and use in source and binary forms, with or without
+// modification, are permitted provided that the following conditions
+// are met:
+// 
+//   * Redistributions of source code must retain the above copyright
+//     notice, this list of conditions and the following disclaimer.  
+// 
+//   * Redistributions in binary form must reproduce the above
+//     copyright notice, this list of conditions and the following
+//     disclaimer in the documentation and/or other materials provided
+//     with the distribution.  
+// 
+//   * Neither the name of the copyright holder nor the names of its
+//     contributors may be used to endorse or promote products derived
+//     from this software without specific prior written permission.
+// 
+// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
+// FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
+// COPYRIGHT HOLDERS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
+// INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+// (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
+// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
+// HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
+// STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
+// ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
+// OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #if !(defined TRNG_UTILITY_HPP)
 
@@ -125,6 +140,9 @@ namespace trng {
     
     // -------------------------------------------------------------------
       
+    template<typename T>
+    class io_range;
+
     template<typename T>
     class io_range {
     private:
@@ -137,34 +155,42 @@ namespace trng {
 					  delim_str(delim_str) {
       }
 
-      template<typename char_t, typename traits_t>
+      template<typename S, typename char_t, typename traits_t>
       friend std::basic_ostream<char_t, traits_t> & 
-      operator<<(std::basic_ostream<char_t, traits_t> &out, const io_range &IO_range) {
-	T pos(IO_range.first);
-	while (out and pos!=IO_range.last) {
-	  out << (*pos);
-	  ++pos;
-	  if (pos!=IO_range.last and IO_range.delim_str!=0)
-	    out << IO_range.delim_str;
-	}
-	return out;
-      }
+      operator<<(std::basic_ostream<char_t, traits_t> &out, const io_range<S> &IO_range);
     
-      template<typename char_t, typename traits_t>
+      template<typename S, typename char_t, typename traits_t>
       friend std::basic_istream<char_t, traits_t> & 
-      operator>>(std::basic_istream<char_t, traits_t> &in, const io_range &IO_range) {
-	T pos(IO_range.first);
-	while (in and pos!=IO_range.last) {
-	  in >> (*pos);
-	  ++pos;
-	  if (pos!=IO_range.last)
-	    in >> delim(IO_range.delim_str);
-	}
-	return in;
-      }
+      operator>>(std::basic_istream<char_t, traits_t> &in, const io_range<S> &IO_range);
     
     };
+
+    template<typename T, typename char_t, typename traits_t>
+    std::basic_ostream<char_t, traits_t> & 
+    operator<<(std::basic_ostream<char_t, traits_t> &out, const io_range<T> &IO_range) {
+      T pos(IO_range.first);
+      while (out and pos!=IO_range.last) {
+	out << (*pos);
+	++pos;
+	if (pos!=IO_range.last and IO_range.delim_str!=0)
+	    out << IO_range.delim_str;
+      }
+      return out;
+    }
     
+    template<typename T, typename char_t, typename traits_t>
+    std::basic_istream<char_t, traits_t> & 
+    operator>>(std::basic_istream<char_t, traits_t> &in, const io_range<T> &IO_range) {
+      T pos(IO_range.first);
+      while (in and pos!=IO_range.last) {
+	in >> (*pos);
+	++pos;
+	if (pos!=IO_range.last)
+	  in >> delim(IO_range.delim_str);
+      }
+      return in;
+    }
+
     template<typename T>
     inline io_range<T> make_io_range(T first, T last, const char *delim_str=0) {
       return io_range<T>(first, last, delim_str);
